@@ -45,7 +45,8 @@ class MetadataDecoder(ScaleDecoder):
                 "MetadataV9Decoder",
                 "MetadataV10Decoder",
                 "MetadataV11Decoder",
-                "MetadataV12Decoder"
+                "MetadataV12Decoder",
+                "MetadataV13Decoder"
             ])
 
             self.metadata = self.process_type(self.version.value)
@@ -1101,6 +1102,205 @@ class MetadataV12Module(ScaleType):
         return result
 
 
+class MetadataV13Decoder(ScaleDecoder):
+
+    def __init__(self, data, sub_type=None, **kwargs):
+        self.version = None
+        self.modules = []
+        self.call_index = {}
+        self.event_index = {}
+
+        super().__init__(data, sub_type, **kwargs)
+
+    def process(self):
+        result_data = {
+            "magicNumber": 1635018093,  # struct.unpack('<L', bytearray.fromhex("6174656d")),
+            "metadata": {
+                "MetadataV13": {
+                    "modules": [],
+                }
+            }
+        }
+
+        self.modules = self.process_type('Vec<MetadataV13Module>').elements
+
+        # Build call and event index
+
+        for module in self.modules:
+            if module.calls is not None:
+                for call_index, call in enumerate(module.calls):
+                    call.lookup = "{:02x}{:02x}".format(module.index, call_index)
+                    self.call_index[call.lookup] = (module, call)
+
+            if module.events is not None:
+                for event_index, event in enumerate(module.events):
+                    event.lookup = "{:02x}{:02x}".format(module.index, event_index)
+                    self.event_index[event.lookup] = (module, event)
+
+        result_data["metadata"]["MetadataV13"]["modules"] = [m.value for m in self.modules]
+        result_data["metadata"]["MetadataV13"]["extrinsic"] = self.process_type("ExtrinsicMetadata").value
+
+        return result_data
+
+
+class MetadataV13Module(ScaleType):
+
+    def __init__(self, data, sub_type=None, **kwargs):
+        self.name = None
+        self.prefix = None
+        self.call_index = None
+        self.has_storage = False
+        self.storage = None
+        self.has_calls = False
+        self.calls = None
+        self.has_events = False
+        self.events = None
+        self.constants = []
+        self.errors = []
+        self.index = None
+        super().__init__(data, sub_type, **kwargs)
+
+    def get_identifier(self):
+        return self.name
+
+    def process(self):
+
+        self.name = self.process_type('Bytes').value
+
+        result = {
+            "name": self.name,
+            "prefix": self.prefix,
+            "storage": self.storage,
+            "calls": self.calls,
+            "events": self.events,
+            "constants": self.constants,
+            "errors": self.errors,
+            "index": self.index
+        }
+
+        self.has_storage = self.process_type('bool').value
+
+        if self.has_storage:
+            # TODO convert to Option<Vec<MetadataModuleStorage>>
+            self.storage = self.process_type('MetadataV13ModuleStorage')
+            result["storage"] = self.storage.value
+            # TODO moved to storage, change data model
+            self.prefix = self.storage.prefix
+            result["prefix"] = self.prefix
+
+        self.has_calls = self.process_type('bool').value
+
+        if self.has_calls:
+            # TODO convert to Option<Vec<MetadataModuleCall>>
+            self.calls = self.process_type('Vec<MetadataModuleCall>').elements
+            result["calls"] = [s.value for s in self.calls]
+
+        self.has_events = self.process_type('bool').value
+
+        if self.has_events:
+            # TODO convert to Option<Vec<MetadataModuleEvent>>
+            self.events = self.process_type('Vec<MetadataModuleEvent>').elements
+            result["events"] = [s.value for s in self.events]
+
+        self.constants = self.process_type('Vec<MetadataV7ModuleConstants>').elements
+        result["constants"] = [s.value for s in self.constants]
+
+        self.errors = self.process_type('Vec<MetadataModuleError>').elements
+        result["errors"] = [s.value for s in self.errors]
+
+        self.index = self.process_type('u8').value
+        result["index"] = self.index
+
+        return result
+
+
+class MetadataV13ModuleStorage(MetadataV7ModuleStorage):
+
+    def __init__(self, data, sub_type=None, **kwargs):
+        self.prefix = None
+        self.items = []
+
+        super().__init__(data, sub_type, **kwargs)
+
+    def process(self):
+
+        self.prefix = self.process_type('Bytes').value
+        self.items = self.process_type('Vec<MetadataV13ModuleStorageEntry>').elements
+
+        return {
+            "prefix": self.prefix,
+            "items": [s.value for s in self.items]
+        }
+
+
+class MetadataV13ModuleStorageEntry(ScaleType):
+
+    def __init__(self, data, sub_type=None, **kwargs):
+        self.name = None
+        self.modifier = None
+        self.type = {}
+        self.fallback = None
+        self.docs = []
+        self.hasher = None
+        super().__init__(data, sub_type, **kwargs)
+
+    def process(self):
+
+        self.name = self.process_type('Bytes').value
+        self.modifier = self.process_type('Enum', value_list=["Optional", "Default"]).value
+
+        storage_function_type = self.process_type(
+            'Enum', value_list=["PlainType", "MapType", "DoubleMapType", "NMap"]
+        ).value
+
+        if storage_function_type == 'MapType':
+            self.hasher = self.process_type('StorageHasher')
+            self.type = {
+                "MapType": {
+                    "hasher": self.hasher.value,
+                    "key": self.convert_type(self.process_type('Bytes').value),
+                    "value": self.convert_type(self.process_type('Bytes').value),
+                    "isLinked": self.process_type('bool').value
+                }
+            }
+        elif storage_function_type == 'DoubleMapType':
+            self.hasher = self.process_type('StorageHasher')
+            self.type = {
+                "DoubleMapType": {
+                    "hasher": self.hasher.value,
+                    "key1": self.convert_type(self.process_type('Bytes').value),
+                    "key2": self.convert_type(self.process_type('Bytes').value),
+                    "value": self.convert_type(self.process_type('Bytes').value),
+                    "key2Hasher": self.process_type('StorageHasher').value
+                }
+            }
+
+        elif storage_function_type == 'PlainType':
+            self.type = {
+                "PlainType": self.convert_type(self.process_type('Bytes').value)
+            }
+        elif storage_function_type == 'NMap':
+            self.type = {
+                "NMapType": {
+                    "hashers": self.process_type('Vec<StorageHasher>').value,
+                    "keys": [self.convert_type(k) for k in self.process_type('Vec<Bytes>').value],
+                    "value": self.convert_type(self.process_type('Bytes').value),
+                }
+            }
+
+        self.fallback = self.process_type('HexBytes').value
+
+        self.docs = self.process_type('Vec<Bytes>').value
+
+        return {
+            "name": self.name,
+            "modifier": self.modifier,
+            "type": self.type,
+            "fallback": self.fallback,
+            "docs": self.docs
+        }
+
+
 class MetadataV3Decoder(ScaleDecoder):
 
     def __init__(self, data, sub_type=None, **kwargs):
